@@ -13,44 +13,11 @@ sub index :Path Args(0) {
     $c->res->body('action: index');
 }
 
-sub login :Local {
-    my ($self, $c) = @_;
-
-    my $creds = {
-        username => $c->req->params->{user},
-        password => $c->req->params->{password},
-    };
-
-    my $uid;
-
-    if ($c->authenticate($creds, 'members')) {
-        $uid = $c->user->id;
-    }
-    else {
-        $uid = '*';
-    }
-
-    $c->res->body("logged in: $uid");
-}
-
-sub logout :Local {
-    my ($self, $c) = @_;
-
-    if (my $user = $c->user) {
-        # we can't wait for sessions to expire on their own
-        $c->delete_session;
-        $user->logout;
-        $c->res->redirect($c->uri_for());
-    }
-    else {
-        $c->detach('denied');
-    }
-}
-
 sub edit
 :Local
 :ActionClass(Role::ACL)
 :RequiresRole(editor)
+:ACLDetachTo(denied)
 {
     my ($self, $c) = @_;
     $c->res->body("action: edit");
@@ -60,6 +27,7 @@ sub killit
 :Local
 :ActionClass(Role::ACL)
 :RequiresRole(killer)
+:ACLDetachTo(denied)
 {
     my ($self, $c) = @_;
     $c->res->body("action: killit");
@@ -70,6 +38,7 @@ sub crews
 :ActionClass(Role::ACL)
 :RequiresRole(editor)
 :RequiresRole(banana)
+:ACLDetachTo(denied)
 {
     my ($self, $c) = @_;
     $c->res->body("action: crews");
@@ -80,29 +49,31 @@ sub reese
 :ActionClass(Role::ACL)
 :AllowedRole(sarah)
 :AllowedRole(shahi)
+:ACLDetachTo(denied)
 {
     my ($self, $c) = @_;
     $c->res->body("action: reese");
 }
 
-sub end :ActionClass('RenderView') {
+sub wolverines
+:Local
+:ActionClass(Role::ACL)
+:RequiresRole('swayze')
+:AllowedRole('actor')
+:AllowedRole('guerilla')
+:ACLDetachTo(denied)
+{
     my ($self, $c) = @_;
-
-    if ($c->res->status == 403) {
-        $c->detach('denied');
-    }
+    $c->res->body("action: wolverines");
 }
 
 sub denied :Private {
     my ($self, $c) = @_;
 
+    $c->res->status(403);
     $c->res->body('access denied');
 }
 
 
 1;
 
-
-__END__
-/usr/lib64/perl5/site_perl/5.8.8/Class/Accessor.pm
-
